#
# spec file for package glasskube-cli
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define executable_name glasskube

Name:           glasskube-cli
Version:        0.26.0
Release:        1.1
Summary:        The next generation Package Manager for Kubernetes
License:        Apache-2.0
URL:            https://github.com/glasskube/glasskube
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.20
BuildRequires:  zsh
Provides:       glasskube = %{version}

%description
Glasskube is an Open Source package manager for Kubernetes. It makes deploying,
updating, and configuring packages on Kubernetes 20 times faster than tools
like Helm or Kustomize. Inspired by the simplicity of Homebrew and npm. You can
decide if you want to use the Glasskube UI, CLI, or directly deploy packages
via GitOps.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
# hash will be shortened by COMMIT_HASH:0:8 later
COMMIT_HASH="$(sed -n 's/commit: \(.*\)/\1/p' %_sourcedir/%{name}.obsinfo)"

DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")

go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X github.com/glasskube/glasskube/internal/config.Version=v%{version} \
   -X github.com/glasskube/glasskube/internal/config.Commit=${COMMIT_HASH:0:8} \
   -X github.com/glasskube/glasskube/internal/config.Date=${BUILD_DATE}" \
   -o bin/%{executable_name} ./cmd/glasskube

%install
# Install the binary.
install -D -m 0755 bin/%{executable_name} %{buildroot}/%{_bindir}/%{executable_name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{executable_name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{executable_name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{executable_name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{executable_name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{executable_name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{executable_name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{executable_name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{executable_name}

%changelog
* Tue Nov 26 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.26.0:
  * no CLI-related changes in the changelog
* Wed Oct 23 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.25.0:
  * chore(main): release 0.25.0 (#1310)
  * docs(website): added initial kustomize guide to website (#1303)
  * feat(website): add testimonials (#1300)
  * chore(deps): update dependency typescript-eslint to v8.11.0
    (#1351)
  * chore(deps): update dependency @eslint/js to v9.13.0 (#1350)
  * feat(website): logo slider (#1299)
  * chore(deps): update dependency typescript-eslint to v8.10.0
    (#1348)
  * docs(website): fix typo's in helm guide (#1340)
  * feat(package-operator): restart dependent workloads when
    package spec changes (#1331)
  * fix(deps): update dependency @getcanary/web to v1.0.10 (#1343)
  * chore(deps): update dependency typescript-eslint to v8.9.0
    (#1342)
  * fix(deps): update module sigs.k8s.io/kustomize/api to v0.18.0
    (#1327)
  * fix(ui): package detail header breaks when rendering (#1332)
  * fix(deps): update module github.com/yuin/goldmark to v1.7.6
    (#1337)
  * fix(deps): update dependency @getcanary/web to v1.0.9 (#1339)
  * fix(deps): update dependency
    @getcanary/docusaurus-theme-search-pagefind to v1.0.2 (#1336)
  * fix(deps): update dependency @getcanary/web to v1.0.8 (#1335)
  * fix(deps): update dependency
    @getcanary/docusaurus-theme-search-pagefind to v1.0.1 (#1334)
  * docs(website): initial helm guide article (#1302)
  * fix(deps): update dependency @getcanary/web to v1.0.7 (#1333)
  * fix(deps): update dependency @getcanary/web to v1.0.6 (#1330)
  * fix(deps): update dependency @getcanary/web to v1.0.4 (#1329)
  * chore(deps): update actions/upload-artifact action to v4.4.3
    (#1328)
  * feat: add suspending package reconciliation and fix shell
    completion (#1315)
  * chore(deps): update dependency globals to v15.11.0 (#1326)
  * fix(deps): update dependency @getcanary/web to v1.0.3 (#1325)
  * fix(deps): update dependency @getcanary/web to v1.0.2 (#1324)
  * chore(deps): update dependency typescript to v5.6.3 (#1323)
  * chore(deps): update actions/upload-artifact action to v4.4.2
    (#1322)
  * chore(deps): update actions/cache action to v4.1.1 (#1321)
  * feat(ui): combine package update and configuration (#1294)
  * chore(deps): update actions/checkout digest to eef6144 (#1319)
  * chore(deps): update dependency typescript-eslint to v8.8.1
    (#1320)
  * chore(deps): update actions/upload-artifact action to v4.4.1
    (#1318)
  * fix(deps): update dependency @getcanary/web to v1 (#1314)
  * fix(deps): update dependency
    @getcanary/docusaurus-theme-search-pagefind to v1 (#1313)
  * chore(deps): update actions/cache action to v4.1.0 (#1311)
  * fix(deps): update module golang.org/x/term to v0.25.0 (#1309)
  * chore(deps): update dependency @eslint/js to v9.12.0 (#1312)
  * fix(deps): update dependency htmx.org to v2.0.3 (#1308)
* Fri Oct  4 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.24.0:
  * chore(main): release 0.24.0 (#1298)
  * feat(package-operator): add "well-known" label field specs
    (#1305)
  * fix(deps): update module github.com/schollz/progressbar/v3 to
    v3.16.1 (#1304)
  * chore(deps): update dependency eslint-plugin-react to v7.37.1
    (#1296)
  * chore(deps): update dependency eslint-plugin-import to v2.31.0
    (#1301)
  * fix(ui): clear previous modal content (#1292)
  * chore(deps): update dependency globals to v15.10.0 (#1297)
* Wed Oct  2 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.23.0:
  * chore(main): release 0.23.0 (#1285)
  * fix(package-operator): add auth support for relative manifest
    urls in package.yaml (#1295)
  * fix(deps): update module
    github.com/fluxcd/source-controller/api to v1.4.1 (#1281)
  * feat: make auto update changeable on UI and show hint (#1291)
  * fix(deps): update module github.com/fluxcd/helm-controller/api
    to v1.1.0 (#1287)
  * chore(deps): update dependency typescript-eslint to v8.8.0
    (#1293)
  * docs(website): fix typo in website (#1290)
  * feat: show conflicts at package update (#1282)
  * chore(docs): fix architecture diagram in readme (#1289)
  * chore(deps): update dependency eslint-plugin-react to v7.37.0
    (#1288)
  * fix: avoid dependency errors during uninstallation (#1284)
  * feat: show package components (#1283)
* Wed Oct  2 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.22.0:
  * chore(main): release 0.22.0 (#1230)
  * feat(ui): improve package detail page (#1253)
  * chore(website): fix broken links (#1280)
  * docs: use a mermaid diagram for the dependency management
    algorithm (#1270)
  * docs(website): fix link to package configuration design
    documentation in guides (#1279)
  * fix: consider metadata when calculating max version (#1276)
  * fix(ui): add text-break inside toast-body (#1278)
  * fix(deps): update dependency
    @getcanary/docusaurus-theme-search-pagefind to ^0.0.15 (#1271)
  * fix(deps): update module github.com/schollz/progressbar/v3 to
    v3.16.0 (#1272)
  * chore(deps): update dependency typescript-eslint to v8.7.0
    (#1275)
  * chore(deps): update dependency @eslint/js to v9.11.1 (#1274)
  * docs(website): fix cert-manager typo (#1273)
  * chore: add docusaurus config to release please for automatic
    banner updates (#1268)
  * chore(deps): update actions/setup-node digest to 0a44ba7
    (#1255)
  * fix: dependency manager uses given repository if known (#1259)
  * chore(deps): update dependency esbuild to v0.24.0 (#1269)
  * docs(website): improve wording (#1267)
  * docs(website): rename cta (#1266)
  * docs(website): improve website wording (#1265)
  * chore(deps): update dependency @eslint/js to v9.11.0 (#1263)
  * fix(deps): update dependency @glasskube/theme to v0.1.2 (#1254)
  * chore(deps): update actions/setup-node action to v4.0.4 (#1256)
  * fix(ui): reopen strategy for portforwardings (#1248)
  * fix(ui): use hardcoded giscus backlink (#1252)
  * fix(ui): error installing clusterpackage (#1247)
  * fix: increase resilience in case of broken repositories (#1237)
  * fix(deps): update module github.com/posthog/posthog-go to
    v1.2.24 (#1244)
  * feat(ui): create namespace at installation (#1246)
  * chore(deps): update dependency typescript-eslint to v8.6.0
    (#1245)
  * chore(deps): update dependency eslint to v8.57.1 (#1243)
  * feat(cli): create namespace if necessary when installing a
    package (#1131)
  * fix(deps): update module github.com/posthog/posthog-go to
    v1.2.22 (#1241)
  * fix(deps): update dependency @getcanary/web to ^0.0.106 (#1239)
  * fix(deps): update module github.com/schollz/progressbar/v3 to
    v3.15.0 (#1240)
  * fix(deps): update dependency
    @getcanary/docusaurus-theme-search-pagefind to ^0.0.14 (#1238)
  * docs: fix spelling errors on website and README (#1236)
  * fix(deps): update fontsource monorepo to v5.1.0 (#1231)
  * feat(cli): unify value config flags and add support for
    `--value` with `--use-default` (#1232)
  * docs(website): added link to package scope section of the
    launch blog (#1234)
  * chore(deps): update dependency eslint-plugin-react to v7.36.1
    (#1233)
  * docs(website): added package scopes page to docs (#1226)
  * chore(deps): update dependency eslint-plugin-react to v7.36.0
    (#1229)
  * fix(deps): update kubernetes packages to v0.31.1 (#1228)
  * fix(deps): update dependency @getcanary/web to ^0.0.105 (#1227)
* Mon Sep 23 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package glasskube-cli: CLI for the Glasskube next generation
  Package Manager for Kubernetes
